<?php

global $language;
$language = array (

'filenotexist'		=>	'File does not exist.  Contact the Flyspray administrator for this project.',
'showtask'			=>	'Show Task',
'now'			=>	'Now',
'go'				=>	'Go!',
'opentaskanon'		=>	'Open a new Task anonymously',
'register'			=>	'Register as a new user',
'loggedinas'		=>	'Logged in as',
//'mytasks'			=>	'My Tasks',
'addnewtask'		=>	'Add new task',
'reports'		=>	'Reports',
'editmydetails'		=>	'Edit my details',
'changepassword'	=>	'Change Password',
'logout'			=>	'Logout',
'options'			=>	'Options',
'usersandgroups'	=>	'Users &amp; Groups',
'tasktypes'			=>	'Task Types',
'categories'		=>	'Categories',
'operatingsystems'	=>	'Operating Systems',
'resolutions'		=>	'Resolutions',
'versions'			=>	'Versions',
'severities'		=>	'Severities',
'disabledaccount'	=>	'Your account has been disabled!<br>Immediately logging you out...',
'poweredby'			=>	'Powered by Flyspray',

// Added in version 0.9.5

//'selectproject'	=>	'Task list for Project:',
'show'				=>	'Show',
'projects'			=>	'Projects',
'adminmenu'			=>	'Admin Menu',

// Added in version 0.9.6
'duplicated'		=>	'Repeated action. Redirecting to main page.',
'allprojects'       =>	'All Projects',
'selectproject'		=>	'for Project:',
'tasksall'          =>  'All tasks',
'tasksassigned'     =>  'Tasks assigned to me',
'tasksreported'     =>  'Tasks reported by me',
'taskswatched'      =>  'Tasks I watch',
'lastsearch'   =>  'My last search',

// Added in version 0.9.7
'adminreqwaiting'   =>   'Admin requests',



);
?>
